pub fn lint(message: &str, config: &LintConfig) -> Vec<LintError>Expand description
Lint a commit message against the given configuration.
First parses the message, then applies additional rules from the config. Returns an empty vec if the message is valid.